@@ -60,36 +60,7 @@ sub read_config {
 		  request_timeout => 30,
 		  return_buffer_size => 1048576, # 1Mb
 		  reverse_path_map => 1,
-		  supported_archs => join(', ', qw(
-						      avr32
-						      amd64
-						      alpha
-						      arm
-						      arm64
-						      armel
-						      armhf
-						      hppa
-						      hurd-i386
-						      i386
-						      ia64
-						      kfreebsd-amd64
-						      kfreebsd-i386
-						      m32r
-						      m68k
-						      mips
-						      mipsel
-						      netbsd-alpha
-						      netbsd-i386
-						      powerpc
-						      powerpcspe
-						      ppc64
-						      s390
-						      s390x
-						      sh4
-						      sparc
-						      sparc64
-						      x32
-						 )),
+		  supported_archs => join(', ', grep { $_ !~ /-/ } Dpkg::Arch::get_valid_arches()),
 		  ubuntu_release_names => join(', ', get_ubuntu_names()),
 		  user => $>,
 
